@@ -27,3 +27,9 @@ biocLite("TxDb.Hsapiens.UCSC.hg19.knownGene")
 biocLite("DEXSeq")
 
 biocLite("BSgenome.Hsapiens.UCSC.hg19")
+
+# from CRAN
+install.packages(repos="http://ftp.sunet.se/pub/lang/CRAN", dependencies=TRUE, pkgs="MKmisc")
+install.packages(repos="http://ftp.sunet.se/pub/lang/CRAN", dependencies=TRUE, pkgs="e1071")
+install.packages(repos="http://ftp.sunet.se/pub/lang/CRAN", dependencies=TRUE, pkgs="GeneCycle")
+install.packages(repos="http://ftp.sunet.se/pub/lang/CRAN", dependencies=TRUE, pkgs="fastICA")
